@@ -15,6 +15,7 @@ Description:
 /***********************************************************************************************
 	Include files
 ***********************************************************************************************/
+#include <cassert>
 #include "main.h"
 
 #ifdef _MSC_VER
@@ -163,15 +164,11 @@ bool GdlRenderer::CheckTablesAndPasses(GrcManager * pcman, int * pcpassValid)
 
 	if (nPassNum >= kMaxPasses)
 	{
-		char rgch1[20];
-		char rgch2[20];
-		itoa(nPassNum, rgch1, 10);
-		itoa(kMaxPasses - 1, rgch2, 10);
 		g_errorList.AddError(3101, NULL,
 			"Number of passes (",
-			rgch1,
+			std::to_string(nPassNum),
 			") exceeds maximum of ",
-			rgch2);
+			std::to_string(kMaxPasses - 1));
 	}
 	else if (nPassNum == 0)
 	{
@@ -194,10 +191,9 @@ void GdlRuleTable::CheckTablesAndPasses(GrcManager * pcman, int *pnPassNum, int
 		// but go ahead and treat it as the zeroth pass for now
 	}
 
-	for (size_t ipass = 0; ipass < m_vppass.size(); ++ipass)
+	for (auto ipass = 0U; ipass < m_vppass.size(); ++ipass)
 	{
-		char rgchPass[20];
-		itoa(ipass, rgchPass, 10);
+		auto const staPass = std::to_string(ipass);
 		if (m_vppass[ipass]->ValidPass())
 		{
 			m_vppass[ipass]->AssignGlobalID(*pnPassNum);
@@ -209,23 +205,21 @@ void GdlRuleTable::CheckTablesAndPasses(GrcManager * pcman, int *pnPassNum, int
 			{
 				g_errorList.AddError(3166, this,
 					"Invalid direction for pass ",
-					rgchPass);
+					staPass);
 			}
 			else if (fsdcPassDir != kfsdcNone && fsdcScriptDir != kfsdcHorizLtr && fsdcScriptDir != kfsdcHorizRtl)
 			{
-				char rgchScrDir[20];
-				itoa(fsdcScriptDir, rgchScrDir, 10);
 				g_errorList.AddError(3167, this,
 					"Direction directive invalid (on pass ",
-					rgchPass,
+					staPass,
 					") due to font ScriptDirection setting of ",
-					rgchScrDir);
+					std::to_string(fsdcScriptDir));
 			}
 			else if (fsdcPassDir != kfsdcNone && fsdcScriptDir == fsdcPassDir)
 			{
 				g_errorList.AddWarning(3539, this,
 					"Direction of pass ",
-					rgchPass,
+					staPass,
 					" matches font's ScriptDirection and will have no effect ");
 			}
 			else
@@ -249,7 +243,7 @@ void GdlRuleTable::CheckTablesAndPasses(GrcManager * pcman, int *pnPassNum, int
 		{
 			g_errorList.AddWarning(3503, this,
 				"Pass ",
-				rgchPass,
+				staPass,
 				" of ",
 				m_psymName->FullName(),
 				" table contains no rules");
@@ -290,20 +284,17 @@ void GdlPass::FixRulePreContexts(Symbol psymAnyClass)
 
 	//	First, calculate the maximum and minimum pre-contexts lengths for all the rules
 	//	in this pass. Also record the original rule length to use as a sort key.
-	size_t iprule;
-	for (iprule = 0; iprule < m_vprule.size(); iprule++)
+	for (auto prule: m_vprule)
 	{
-		int crit = m_vprule[iprule]->CountRulePreContexts();
+		auto crit = prule->CountRulePreContexts();
 		m_critMinPreContext = min(m_critMinPreContext, crit);
 		m_critMaxPreContext = max(m_critMaxPreContext, crit);
 	}
 
 	//	Now add "ANY" class slots to the beginning of each rule to make every rule have
 	//	the same number of pre-context items.
-	for (iprule = 0; iprule < m_vprule.size(); iprule++)
-	{
-		m_vprule[iprule]->FixRulePreContexts(psymAnyClass, m_critMaxPreContext);
-	}
+	for (auto prule: m_vprule)
+		prule->FixRulePreContexts(psymAnyClass, int(m_critMaxPreContext));
 }
 
 /*----------------------------------------------------------------------------------------------
@@ -311,14 +302,14 @@ void GdlPass::FixRulePreContexts(Symbol psymAnyClass)
 	Also record the original rule length to use as a sort key (before it is modified
 	by adding ANY classes to the beginning of the rule).
 ----------------------------------------------------------------------------------------------*/
-int GdlRule::CountRulePreContexts()
+size_t GdlRule::CountRulePreContexts()
 {
 	m_critOriginal = m_vprit.size();
 
 	m_critPreModContext = 0;
-	for (size_t irit = 0; irit < m_vprit.size(); irit++)
+	for (auto const &rit:  m_vprit)
 	{
-		if (dynamic_cast<GdlSetAttrItem *>(m_vprit[irit]))
+		if (dynamic_cast<GdlSetAttrItem *>(rit))
 			return m_critPreModContext;
 		m_critPreModContext++;
 	}
@@ -338,7 +329,7 @@ void GdlRule::FixRulePreContexts(Symbol psymAnyClass, int critNeeded)
 	if (m_critPrependedAnys == 0)
 		return;
 
-	for (int iritToAdd = 0; iritToAdd < m_critPrependedAnys; iritToAdd++)
+	for (auto iritToAdd = 0U; iritToAdd < m_critPrependedAnys; ++iritToAdd)
 	{
 		GdlRuleItem * prit = new GdlRuleItem(psymAnyClass);
 		prit->SetLineAndFile(LineAndFile());
@@ -348,15 +339,15 @@ void GdlRule::FixRulePreContexts(Symbol psymAnyClass, int critNeeded)
 
 	//	Increment the item positions following the inserted items, and adjust any slot
 	//	references.
-	for (int irit = m_critPrependedAnys; irit < signed(m_vprit.size()); irit++)
+	for (auto irit = m_critPrependedAnys; irit < m_vprit.size(); ++irit)
 	{
-		m_vprit[irit]->IncContextPosition(m_critPrependedAnys);
-		m_vprit[irit]->AdjustSlotRefsForPreAnys(m_critPrependedAnys);
+		m_vprit[irit]->IncContextPosition(int(m_critPrependedAnys));
+		m_vprit[irit]->AdjustSlotRefsForPreAnys(int(m_critPrependedAnys));
 	}
 
 	//	Increment the scan advance position, if any.
 	if (m_nScanAdvance > -1)
-		m_nScanAdvance += m_critPrependedAnys;
+		m_nScanAdvance += int(m_critPrependedAnys);
 }
 
 /*----------------------------------------------------------------------------------------------
@@ -480,15 +471,11 @@ bool GrcManager::AssignClassInternalIDs()
 
 	if (nSubID >= kMaxReplcmtClasses)
 	{
-		char rgch1[20];
-		char rgch2[20];
-		itoa(nSubID, rgch1, 10);
-		itoa(kMaxReplcmtClasses - 1, rgch2, 10);
 		g_errorList.AddError(3103, NULL,
 			"Number of classes used in glyph substitution (",
-			rgch1,
+			std::to_string(nSubID),
 			") exceeds maximum of ",
-			rgch2);
+			std::to_string(kMaxReplcmtClasses - 1));
 	}
 
 	return true;
@@ -537,15 +524,14 @@ void GdlRule::MarkReplacementClasses(GrcManager * pcman, int nPassID,
 	std::vector<bool> vfOutput;
 	vfInput.resize(m_vprit.size(), false);
 	vfOutput.resize(m_vprit.size(), false);
-	size_t irit;
 
-	for (irit = 0; irit < m_vprit.size(); irit++)
+	for (auto irit = 0U; irit < m_vprit.size(); ++irit)
 	{
 		m_vprit[irit]->AssignFsmInternalID(pcman, nPassID);
 		m_vprit[irit]->FindSubstitutionSlots(irit, vfInput, vfOutput);
 	}
 
-	for (irit = 0; irit < m_vprit.size(); irit++)
+	for (auto irit = 0U; irit < m_vprit.size(); ++irit)
 	{
 		if (vfInput[irit])
 			m_vprit[irit]->MarkClassAsReplacementClass(pcman, setpglfcReplace, true);
@@ -584,7 +570,7 @@ void GrcManager::AddToFsmClasses(GdlGlyphClassDefn * pglfc, int nPassID)
 		Assert((*pvpglfcThisPass)[pglfc->FsmID(nPassID)] == pglfc);
 		return;
 	}
-	pglfc->MarkFsmClass(nPassID, pvpglfcThisPass->size());
+	pglfc->MarkFsmClass(nPassID, int(pvpglfcThisPass->size()));
 	pvpglfcThisPass->push_back(pglfc);
 }
 
@@ -698,21 +684,17 @@ void GdlRuleItem::MarkClassAsReplacementClass(GrcManager * pcman,
 		int cw = pglfc->GlyphIDCount();
 		if (cw > kMaxGlyphsPerInputClass)
 		{
-			char rgchMax[20];
-			itoa(kMaxGlyphsPerInputClass, rgchMax, 10);
-			char rgchCount[20];
-			itoa(cw, rgchCount, 10);
 			g_errorList.AddError(3105, this,
 				"Number of glyphs (",
-				rgchCount,
+				std::to_string(cw),
 				") in class ",
 				pglfc->Name(),
 				" exceeds maximum of ",
-				rgchMax,
+				std::to_string(kMaxGlyphsPerInputClass),
 				" allowed for input side of substitution");
 		}
 
-		utf16 wGlyphIDDup;
+		gid16 wGlyphIDDup;
         if (pglfc->HasDuplicateGlyphs(&wGlyphIDDup))
         {
             g_errorList.AddError(3172, this,
@@ -770,7 +752,7 @@ void GdlRuleTable::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont * pfon
 		grfrco = (kfrcoSetBreak | kfrcoSetDir | kfrcoPreBidi);
 	else if (m_psymName->LastFieldIs("substitution"))
 		grfrco = (kfrcoLb | kfrcoSubst | kfrcoSetCompRef | kfrcoSetDir |
-					kfrcoSetInsert | kfrcoPreBidi);
+					kfrcoPreBidi);   // kfrcoSetInsert | 
 	else if (m_psymName->LastFieldIs("justification"))
 		grfrco = (kfrcoNeedJust | kfrcoLb | kfrcoSubst | kfrcoSetCompRef |
 					kfrcoSetInsert);
@@ -803,15 +785,11 @@ void GdlRule::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont * pfont,
 {
 	if (m_vprit.size() > kMaxSlotsPerRule)
 	{
-		char rgchMax[20];
-		itoa(kMaxSlotsPerRule, rgchMax, 10);
-		char rgchCount[20];
-		itoa(m_vprit.size(), rgchCount, 10);
 		g_errorList.AddError(3106, this,
 			"Number of slots (",
-			rgchCount,
+			std::to_string(m_vprit.size()),
 			") exceeds maximum of ",
-			rgchMax);
+			std::to_string(kMaxSlotsPerRule));
 	}
 
 	//	Create lists of flags indicating which items are line-break items, insertions,
@@ -828,8 +806,8 @@ void GdlRule::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont * pfont,
 	std::vector<int> vcwClassSizes;
 	vcwClassSizes.resize(crit, false);
 	bool fAnyAssocs = false;
-	size_t irit;
-	for (irit = 0; irit < crit; irit++)
+
+	for (auto irit = 0U; irit < crit; ++irit)
 	{
 		GdlRuleItem * prit = m_vprit[irit];
 		GdlLineBreakItem * pritlb = dynamic_cast<GdlLineBreakItem *>(prit);
@@ -882,7 +860,7 @@ void GdlRule::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont * pfont,
 	}
 
 	//	Do the checks for each item.
-	for (irit = 0; irit < crit; irit++)
+	for (auto irit = 0U; irit < crit; ++irit)
 	{
 //		if (m_nScanAdvance > -1 && irit >= m_nScanAdvance &&
 //			(vfInsertion[irit] || vfDeletion[irit]))
@@ -1101,9 +1079,8 @@ bool GdlSubstitutionItem::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont
 					}
 					else
 					{
-						char rgch[20];
-						itoa(int(iritAssoc + 1 - prule->PrependedAnys()), rgch, 10);
-						for (int irit = 0; irit < prule->NumberOfSlots(); irit++)
+						auto const staAssoc = std::to_string(iritAssoc + 1 - prule->PrependedAnys());
+						for (auto irit = 0U; irit < prule->NumberOfSlots(); ++irit)
 						{
 							GdlRuleItem * prit = prule->Item(irit);
 							if (prit->OutputSymbol()->FullName() != "ANY")
@@ -1112,7 +1089,7 @@ bool GdlSubstitutionItem::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont
 								if (irit != iritAssoc)
 									g_errorList.AddWarning(3532, this,
 										"Item ", prit->PosString(),
-										": slot ", rgch, " automatically associated with deleted item");
+										": slot ", staAssoc, " automatically associated with deleted item");
 							}
 						}
 						prule->SetAutoAssocDone();
@@ -1125,7 +1102,7 @@ bool GdlSubstitutionItem::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont
 						": no slot was associated with deleted item");
 				}
 
-				for (size_t ipavs = 0; ipavs < m_vpavs.size(); ipavs++)
+				for (auto ipavs = 0U; ipavs < m_vpavs.size(); ++ipavs)
 				{
 					if (m_vpavs[ipavs]->AttrName()->IsPassKeySlot())
 					{
@@ -1181,18 +1158,18 @@ bool GdlSubstitutionItem::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont
 					}
 					else
 					{
-						for (int irit = 0; irit < prule->NumberOfSlots(); irit++)
+						auto const iAssoc = int(iritAssoc + 1 - prule->PrependedAnys());
+						auto const staAssoc = std::to_string(iAssoc);
+						for (auto irit = 0U; irit < prule->NumberOfSlots(); ++irit)
 						{
 							GdlRuleItem * prit = prule->Item(irit);
 							if (prit->OutputSymbol()->FullName() != "ANY"
 								&& irit != iritAssoc)
 							{
-								prit->AddAssociation(prule->LineAndFile(), iritAssoc + 1 - prule->PrependedAnys()); // 1-based
-								char rgch[20];
-								itoa(int(iritAssoc + 1 - prule->PrependedAnys()), rgch, 10);
+								prit->AddAssociation(prule->LineAndFile(), iAssoc); // 1-based
 								g_errorList.AddWarning(3533, this,
 									"Item ", prit->PosString(),
-									": inserted item automatically associated with slot ", rgch);
+									": inserted item automatically associated with slot ", staAssoc);
 							}
 						}
 						prule->SetAutoAssocDone();
@@ -1439,7 +1416,7 @@ bool GdlAttrValueSpec::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont *
 		fOkay = false;
 	}
 
-	else if (m_psymName->IsMovement())
+	else if (m_psymName->IsMovement())  // shift, kern, advance
 	{
 		if ((grfrco & kfrcoSetPos) == 0)
 		{
@@ -1462,18 +1439,16 @@ bool GdlAttrValueSpec::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont *
 
 	else if (m_psymName->IsAttachment())
 	{
-		// Go ahead and allow this - Graphite2 is happy with it and it is
-		// helpful in some circumstances.
-		//if ((grfrco & kfrcoSetPos) == 0)
-		//{
-		//	g_errorList.AddError(3122, this,
-		//		"Cannot set the ",
-		//		m_psymName->FullName(),
-		//		" attribute in the ",
-		//		psymTable->FullName(),
-		//		" table");
-		//	fOkay = false;
-		//}
+		if ((grfrco & kfrcoSetPos) == 0)
+		{
+			g_errorList.AddError(3122, this,
+				"Cannot set the ",
+				m_psymName->FullName(),
+				" attribute in the ",
+				psymTable->FullName(),
+				" table");
+			fOkay = false;
+		}
 		GdlGlyphClassDefn * pglfcTmp = prit->OutputSymbol()->GlyphClassDefnData();
 		if (pglfcTmp && pglfcTmp->IncludesGlyph(g_cman.LbGlyphId()))
 		{
@@ -1535,7 +1510,17 @@ bool GdlAttrValueSpec::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont *
 
 	else if (m_psymName->DoesJustification())
 	{
-		if (grfrco & kfrcoPreBidi)
+		// Engine does not permit these in the substitution table.
+		if (grfrco & kfrcoSubst)
+		{
+			g_errorList.AddError(3173, this,
+				"Cannot set the ",
+				m_psymName->FullName(),
+				" in the ",
+				psymTable->FullName(),
+				" table");
+		}
+		else if (grfrco & kfrcoPreBidi)
 		{
 			if (m_psymName->LastFieldIs("width"))
 			{
@@ -1560,36 +1545,43 @@ bool GdlAttrValueSpec::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont *
 
 	else if (m_psymName->IsMeasureAttr())
 	{
-		// These can pretty much go anywhere, as far as I can see.
+		// Engine does not permit these in the substitution table.
+		if (grfrco & kfrcoSubst)
+		{
+			g_errorList.AddError(3173, this,
+				"Cannot set ",
+				m_psymName->FullName(),
+				" in the ",
+				psymTable->FullName(),
+				" table");
+		}
 	}
 
 	else if (m_psymName->IsCollisionAttr())
 	{
-		// You don't expect these in the substitution table, but they don't hurt,
-		// and they *could* go on the last substitution pass.
-		if ((grfrco & kfrcoSetPos) == 0)
+		// Engine does not permit these in the substitution table.
+		if (grfrco & kfrcoSubst)
 		{
-			g_errorList.AddWarning(3534, this,
-				"Setting a collision attribute (",
+			g_errorList.AddError(3173, this,
+				"Cannot set the ",
 				m_psymName->FullName(),
-				") in the ",
+				" attribute in the ",
 				psymTable->FullName(),
-				" table; normally these are set in the positioning table");
+				" table");
 		}
 	}
 
 	else if (m_psymName->IsSequenceAttr())
 	{
-		// You don't expect these in the substitution table, but they don't hurt,
-		// and they *could* go on the last substitution pass.
-		if ((grfrco & kfrcoSetPos) == 0)
+		// Engine does not permit these in the substitution table.
+		if (grfrco & kfrcoSubst)
 		{
-			g_errorList.AddWarning(3534, this,
-				"Setting a sequence attribute (",
+			g_errorList.AddError(3173, this,
+				"Cannot set the ",
 				m_psymName->FullName(),
-				") in the ",
+				" attribute in the ",
 				psymTable->FullName(),
-				" table; normally these are set in the positioning table");
+				" table");
 		}
 	}
 
@@ -1604,11 +1596,9 @@ bool GdlAttrValueSpec::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont *
 		}
 		else if (nIndex >= kMaxUserDefinableSlotAttrs)
 		{
-			char rgch[20];
-			itoa(kMaxUserDefinableSlotAttrs, rgch, 10);
 			g_errorList.AddError(3128, this,
 				"Invalid slot attribute: ", m_psymName->FullName(),
-				"; maximum is ", rgch);
+				"; maximum is ", std::to_string(kMaxUserDefinableSlotAttrs));
 			fOkay = false;
 		}
 		else
@@ -1697,7 +1687,7 @@ bool GdlAttrValueSpec::CheckRulesForErrors(GrcGlyphAttrMatrix * pgax, GrcFont *
 			if (pexpil)
 			{
 				pexpil->SetGlyphIndex(0); // should only be one glyph possible
-				int cValues = pexpil->ValueCount();
+				auto cValues = pexpil->ValueCount();
 				if (cValues == 0)
 					g_errorList.AddError(3163, this,
 							"No glyphs in class ", pexpil->Name()->FullName());
@@ -2426,7 +2416,7 @@ void GdlSetAttrItem::RewriteSlotAttrAssignments(GrcManager * pcman, GrcFont * pf
 	int ipavsColRange = -1;
 	int ipavsColPriority = -1;
 
-	for (size_t ipavs = 0; ipavs < m_vpavs.size(); ipavs++)
+	for (auto ipavs = 0U; ipavs < m_vpavs.size(); ++ipavs)
 	{
 		GdlAttrValueSpec * pavsShift;
 		GdlAttrValueSpec * pavsAdvance;
@@ -2524,9 +2514,9 @@ void GdlSetAttrItem::MergeColRangeAndPriority(GrcManager * pcman, GrcFont * pfon
 	Symbol psymCollisionFlags = pcman->SymbolTable()->FindSymbol(GrcStructName("collision", "flags"));
 	Symbol psymEquals = pcman->SymbolTable()->FindSymbol("=");
 
-	GdlExpression * pexpFlagsOld = NULL;
-	GdlExpression * pexpRange = NULL;
-	GdlExpression * pexpPriority = NULL;
+	GdlExpression * pexpFlagsOld = nullptr;
+	GdlExpression * pexpRange = nullptr;
+	GdlExpression * pexpPriority = nullptr;
 	if (ipavsFlags >= 0)
 		pexpFlagsOld = m_vpavs[ipavsFlags]->m_pexpValue->Clone();
 	if (ipavsRange >= 0)
@@ -2535,7 +2525,7 @@ void GdlSetAttrItem::MergeColRangeAndPriority(GrcManager * pcman, GrcFont * pfon
 		pexpPriority = m_vpavs[ipavsPriority]->m_pexpValue->Clone();
 
 	Symbol psymPlus = pcman->SymbolTable()->FindSymbol("+");
-	GdlExpression * pexpFlagsTemp;
+	GdlExpression * pexpFlagsTemp = nullptr;
 	GdlExpression * pexpFlags;
 	SymbolSet setpsymBogus;
 	bool fCanSub;
@@ -2554,6 +2544,7 @@ void GdlSetAttrItem::MergeColRangeAndPriority(GrcManager * pcman, GrcFont * pfon
 	else if (pexpPriority)
 		pexpFlagsTemp = pexpPriority;
 
+	assert(pexpFlagsTemp);
 	pexpFlags = pexpFlagsTemp->SimplifyAndUnscale(pcman->GlyphAttrMatrix(), -1, setpsymBogus, pfont, false, &fCanSub);
 	if (pexpFlagsTemp != pexpFlags)
 		delete pexpFlagsTemp;
@@ -2861,7 +2852,7 @@ int GdlRule::ItemCountOriginal()
 int GdlRule::FindAutoAssocItem(bool fDelete)
 {
 	int iritResult = -1;
-	for (size_t irit = 0; irit <m_vprit.size(); irit++)
+	for (auto irit = 0U; irit < m_vprit.size(); ++irit)
 	{
 		GdlRuleItem * prit = m_vprit[irit];
 		if (prit->OutputSymbol()->FullName() == "ANY")
