@@ -132,7 +132,7 @@ public:
 
 
 	//	Compiler:
-	virtual void GenerateEngineCode(int fxdRuleVersion, std::vector<gr::byte> & vbOutput,
+	virtual void GenerateEngineCode(uint32_t fxdRuleVersion, std::vector<gr::byte> & vbOutput,
 		int irit, std::vector<int> * pviritInput, int nIIndex,
 		bool fAttachAt, int iritAttachTo, int * pnValue) = 0;
 
@@ -273,7 +273,7 @@ public:
 	}
 
 	//	Compiler:
-	virtual void GenerateEngineCode(int /*fxdRuleVersion*/, std::vector<gr::byte> & /*vbOutput*/,
+	virtual void GenerateEngineCode(uint32_t /*fxdRuleVersion*/, std::vector<gr::byte> & /*vbOutput*/,
 		int /*irit*/, std::vector<int> * /*pviritInput*/, int /*nIIndex*/,
 		bool /*fAttachAt*/, int /*iritAttachTo*/, int * /*pnValue*/)
 	{
@@ -386,7 +386,7 @@ public:
 	virtual bool CompatibleWithVersion(int fxdVersion, int * pfxdNeeded, int * pfxdCpilrNeeded);
 
 	//	Compiler:
-	virtual void GenerateEngineCode(int fxdRuleVersion, std::vector<gr::byte> & vbOutput,
+	virtual void GenerateEngineCode(uint32_t fxdRuleVersion, std::vector<gr::byte> & vbOutput,
 		int irit, std::vector<int> * pviritInput, int nIIndex,
 		bool fAttachAt, int iritAttachTo, int * pnValue);
 	void SetValue(int nValue) { m_nValue = nValue; }
@@ -498,7 +498,7 @@ public:
 	virtual bool CompatibleWithVersion(int fxdVersion, int * pfxdNeeded, int * pfxdCpilrNeeded);
 
 	//	Compiler:
-	virtual void GenerateEngineCode(int fxdRuleVersion, std::vector<gr::byte> & vbOutput,
+	virtual void GenerateEngineCode(uint32_t fxdRuleVersion, std::vector<gr::byte> & vbOutput,
 		int irit, std::vector<int> * pviritInput, int nIIndex,
 		bool fAttachAt, int iritAttachTo, int * pnValue);
 
@@ -597,7 +597,7 @@ public:
 	std::string StringValue() { return m_staValue; }
 
 	//	Compiler:
-	virtual void GenerateEngineCode(int fxdRuleVersion, std::vector<gr::byte> & vbOutput,
+	virtual void GenerateEngineCode(uint32_t fxdRuleVersion, std::vector<gr::byte> & vbOutput,
 		int irit, std::vector<int> * pviritInput, int nIIndex,
 		bool fAttachAt, int iritAttachTo, int * pnValue);
 
@@ -692,7 +692,7 @@ public:
 	virtual bool CompatibleWithVersion(int fxdVersion, int * pfxdNeeded, int * pfxdCpilrNeeded);
 
 	//	Compiler:
-	virtual void GenerateEngineCode(int fxdRuleVersion, std::vector<gr::byte> & vbOutput,
+	virtual void GenerateEngineCode(uint32_t fxdRuleVersion, std::vector<gr::byte> & vbOutput,
 		int irit, std::vector<int> * pviritInput, int nIIndex,
 		bool fAttachAt, int iritAttachTo, int * pnValue);
 
@@ -795,10 +795,10 @@ public:
 	virtual bool CheckAttachToLookup();
 
 	//	Compiler:
-	virtual void GenerateEngineCode(int fxdRuleVersion, std::vector<gr::byte> & vbOutput,
+	virtual void GenerateEngineCode(uint32_t fxdRuleVersion, std::vector<gr::byte> & vbOutput,
 		int irit, std::vector<int> * pviritInput, int nIIndex,
 		bool fAttachAt, int iritAttachTo, int * pnValue);
-	bool GenerateSetBitsOp(int fxdRuleVersion, std::vector<gr::byte> & vbOutput,
+	bool GenerateSetBitsOp(uint32_t fxdRuleVersion, std::vector<gr::byte> & vbOutput,
 		int iritCurrent, std::vector<int> * pviritInput, int nIIndex,
 		bool fAttachAt, int iritAttachTo);
 
@@ -908,7 +908,7 @@ public:
 	virtual bool CompatibleWithVersion(int fxdVersion, int * pfxdNeeded, int * pfxdCpilrNeeded);
 
 	//	Compiler:
-	virtual void GenerateEngineCode(int fxdRuleVersion, std::vector<gr::byte> & vbOutput,
+	virtual void GenerateEngineCode(uint32_t fxdRuleVersion, std::vector<gr::byte> & vbOutput,
 		int irit, std::vector<int> * pviritInput, int nIIndex,
 		bool fAttachAt, int iritAttachTo, int * pnValue);
 
@@ -1018,9 +1018,9 @@ public:
 		:	GdlExpression(exp),
 			m_psymName(exp.m_psymName),
 			m_nClusterLevel(exp.m_nClusterLevel),
+			m_fGlyphAttr(exp.m_fGlyphAttr),
 			m_nInternalID(exp.m_nInternalID),
-			m_nSubIndex(exp.m_nSubIndex),
-			m_fGlyphAttr(exp.m_fGlyphAttr)
+			m_nSubIndex(exp.m_nSubIndex)
 	{
 		m_pexpSelector =
 			(exp.m_pexpSelector) ?
@@ -1101,7 +1101,7 @@ public:
 	virtual bool CompatibleWithVersion(int fxdVersion, int * pfxdNeeded, int * pfxdCpilrNeeded);
 
 	//	Compiler:
-	virtual void GenerateEngineCode(int fxdRuleVersion, std::vector<gr::byte> & vbOutput,
+	virtual void GenerateEngineCode(uint32_t fxdRuleVersion, std::vector<gr::byte> & vbOutput,
 		int irit, std::vector<int> * pviritInput, int nIIndex,
 		bool fAttachAt, int iritAttachTo, int * pnValue);
 
@@ -1180,11 +1180,11 @@ public:
 		GdlExpression ** ppexpGpoint,
 		GdlExpression ** ppexpXoffset, GdlExpression ** ppexpYoffset);
 
-	int ValueCount();
+	size_t ValueCount();
 
 	// Compiler:
 	virtual bool CompatibleWithVersion(int fxdVersion, int * pfxdNeeded, int * pfxdCpilrNeeded);
-	virtual void GenerateEngineCode(int fxdRuleVersion, std::vector<gr::byte> & vbOutput,
+	virtual void GenerateEngineCode(uint32_t fxdRuleVersion, std::vector<gr::byte> & vbOutput,
 		int iritCurrent, std::vector<int> * pviritInput, int nIIndex,
 		bool fAttachAt, int iritAttachTo, int * pnValue);
 
