@@ -75,7 +75,7 @@ public:
 		return fRet;
 	}
 
-	int NumScriptTags()
+	size_t NumScriptTags()
 	{
 		return m_vnScriptTags.size();
 	}
@@ -129,17 +129,17 @@ public:
 	bool CheckSelectors();
 
 	//	Pre-compiler:
-	bool PreCompileFeatures(GrcManager * pcman, GrcFont * pfont, int * pfxdFeatVersion);
+	bool PreCompileFeatures(GrcManager * pcman, GrcFont * pfont, uint32_t * pfxdFeatVersion);
 	void CheckLanguageFeatureSize();
 	bool CheckRecursiveGlyphClasses();
-	int ExplicitPseudos(PseudoSet & setpglf);
+	size_t ExplicitPseudos(PseudoSet & setpglf);
 	int ActualForPseudo(utf16 wPseudo);
-	bool AssignGlyphIDs(GrcFont *, utf16 wGlyphIDLim,
+	bool AssignGlyphIDs(GrcFont *, gid16 wGlyphIDLim,
 		std::map<utf16, utf16> & hmActualForPseudos);
 	void AssignGlyphAttrsToClassMembers(GrcGlyphAttrMatrix * pgax,
 		GrcLigComponentList * plclist);
 	void AssignGlyphAttrDefaultValues(GrcFont * pfont,
-		GrcGlyphAttrMatrix * pgax, int cwGlyphs,
+		GrcGlyphAttrMatrix * pgax, size_t cwGlyphs,
 		std::vector<Symbol> & vpsymSysDefined, std::vector<int> & vnSysDefValues,
 		std::vector<GdlExpression *> & vpexpExtra,
 		std::vector<Symbol> & vpsymGlyphAttrs);
@@ -163,24 +163,22 @@ public:
 		bool * pfFixPassConstraints);
 	void MovePassConstraintsToRules(int fxdSilfVersion);
 	void CalculateSpaceContextuals(GrcFont * pfont);
-	int NumberOfPasses()
+	size_t NumberOfPasses()
 	{
-		int cpass, cpassLB, cpassSub, cpassPos, cpassJust, ipassBidi;
-		CountPasses(&cpass, &cpassLB, &cpassSub, &cpassJust, &cpassPos, &ipassBidi);
+		size_t cpass, cpassLB, cpassSub, cpassPos, cpassJust;
+		int ipassBidi;
+		CountPasses(cpass, cpassLB, cpassSub, cpassJust, cpassPos, ipassBidi);
 		return cpass;
 	}
 
-	void SetNumUserDefn(int c);
-	int NumUserDefn()
+	void SetNumUserDefn(size_t c);
+	size_t NumUserDefn()
 	{
 		return m_cnUserDefn;
 	}
 
-	void SetNumLigComponents(int c);
-	//{
-	//	m_cnComponents = max(m_cnComponents, c);
-	//}
-	int NumLigComponents()
+	void SetNumLigComponents(size_t c);
+	size_t NumLigComponents()
 	{
 		return m_cnComponents;
 	}
@@ -230,18 +228,18 @@ public:
 
 	//	Output:
 	void OutputReplacementClasses(int fxdSilfVersion,
-		std::vector<GdlGlyphClassDefn *> & vpglfc, int cpglfcLinear,
+		std::vector<GdlGlyphClassDefn *> & vpglfc, size_t cpglfcLinear,
 		GrcBinaryStream * pbstrm);
-	void CountPasses(int * pcpass, int * pcpassLB, int * pcpassSub,
-		int * pcpassJust, int * pcpassPos, int * pipassBidi);
-	void OutputPasses(GrcManager * pcman, GrcBinaryStream * pbstrm, long lTableStart,
-		std::vector<int> & vnOffsets);
+	void CountPasses(size_t & pcpass, size_t & pcpassLB, size_t & pcpassSub,
+		size_t & pcpassJust, size_t & pcpassPos, int & pipassBidi);
+	void OutputPasses(GrcManager * pcman, GrcBinaryStream * pbstrm, offset_t lTableStart,
+		std::vector<offset_t> & vnOffsets);
 	bool AssignFeatTableNameIds(utf16 wFirstNameId, utf16 wNameIdMinNew,
 		std::vector<std::wstring> & vstuExtNames, std::vector<utf16> & vwLangIds, 
 		std::vector<utf16> & vwNameTblIds, size_t & cchwStringData,
 		uint8 * pNameTbl, std::vector<GdlFeatureDefn *> & vpfeatInput);
-	void OutputFeatTable(GrcBinaryStream * pbstrm, long lTableStart, int fxdVersion);
-	void OutputSillTable(GrcBinaryStream * pbstrm, long lTableStart);
+	void OutputFeatTable(GrcBinaryStream * pbstrm, offset_t lTableStart, int fxdVersion);
+	void OutputSillTable(GrcBinaryStream * pbstrm, offset_t lTableStart);
 
 protected:
 	//	Instance variables:
@@ -272,8 +270,8 @@ protected:
 	//	space contextuals:
 	SpaceContextuals m_spcon;
 
-	int m_cnUserDefn;	// number of user-defined slot attributes
-	int m_cnComponents;	// max number of components per ligature
+	size_t m_cnUserDefn;	// number of user-defined slot attributes
+	size_t m_cnComponents;	// max number of components per ligature
 
 	enum { kInfiniteXlbContext = 255 };
 };
