@@ -375,9 +375,8 @@ tryAgain:;
 }
 
 void GrpLexer::mWS(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = WS;
-	int _saveIndex;
 	
 	{
 	switch ( LA(1)) {
@@ -432,9 +431,8 @@ void GrpLexer::mWS(bool _createToken) {
 }
 
 void GrpLexer::mCOMMENT_SL(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = COMMENT_SL;
-	int _saveIndex;
 	
 	match("//");
 	{
@@ -460,9 +458,8 @@ void GrpLexer::mCOMMENT_SL(bool _createToken) {
 }
 
 void GrpLexer::mCOMMENT_ML(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = COMMENT_ML;
-	int _saveIndex;
 	
 	match("/*");
 	{
@@ -755,9 +752,8 @@ void GrpLexer::mCOMMENT_ML(bool _createToken) {
 }
 
 void GrpLexer::mLIT_INT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = LIT_INT;
-	int _saveIndex;
 	
 	{
 	if ((LA(1)==static_cast<unsigned char>('0')) && (LA(2)==static_cast<unsigned char>('x'))) {
@@ -825,9 +821,8 @@ void GrpLexer::mLIT_INT(bool _createToken) {
 }
 
 void GrpLexer::mDIGIT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = DIGIT;
-	int _saveIndex;
 	
 	matchRange(static_cast<unsigned char>('0'),static_cast<unsigned char>('9'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -838,9 +833,8 @@ void GrpLexer::mDIGIT(bool _createToken) {
 }
 
 void GrpLexer::mXDIGIT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = XDIGIT;
-	int _saveIndex;
 	
 	switch ( LA(1)) {
 	case static_cast<unsigned char>('0'):
@@ -890,9 +884,8 @@ void GrpLexer::mXDIGIT(bool _createToken) {
 }
 
 void GrpLexer::mLIT_UHEX(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = LIT_UHEX;
-	int _saveIndex;
 	
 	match("U+");
 	{
@@ -917,11 +910,10 @@ void GrpLexer::mLIT_UHEX(bool _createToken) {
 }
 
 void GrpLexer::mLIT_CHAR(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = LIT_CHAR;
-	int _saveIndex;
-	
-	_saveIndex=text.length();
+	auto _saveIndex=text.length();
+
 	mSQUOTE(false);
 	text.erase(_saveIndex);
 	{
@@ -949,9 +941,8 @@ void GrpLexer::mLIT_CHAR(bool _createToken) {
 }
 
 void GrpLexer::mSQUOTE(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = SQUOTE;
-	int _saveIndex;
 	
 	{
 	switch ( LA(1)) {
@@ -984,9 +975,8 @@ void GrpLexer::mSQUOTE(bool _createToken) {
 }
 
 void GrpLexer::mESC(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = ESC;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('\\'));
 	{
@@ -1045,11 +1035,10 @@ void GrpLexer::mESC(bool _createToken) {
 }
 
 void GrpLexer::mLIT_STRING(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = LIT_STRING;
-	int _saveIndex;
+	auto _saveIndex=text.length();
 	
-	_saveIndex=text.length();
 	mDQUOTE(false);
 	text.erase(_saveIndex);
 	{
@@ -1080,9 +1069,8 @@ void GrpLexer::mLIT_STRING(bool _createToken) {
 }
 
 void GrpLexer::mDQUOTE(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = DQUOTE;
-	int _saveIndex;
 	
 	{
 	switch ( LA(1)) {
@@ -1115,9 +1103,8 @@ void GrpLexer::mDQUOTE(bool _createToken) {
 }
 
 void GrpLexer::mODIGIT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = ODIGIT;
-	int _saveIndex;
 	
 	matchRange(static_cast<unsigned char>('0'),static_cast<unsigned char>('7'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1128,9 +1115,8 @@ void GrpLexer::mODIGIT(bool _createToken) {
 }
 
 void GrpLexer::mOP_DOT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_DOT;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('.'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1141,9 +1127,8 @@ void GrpLexer::mOP_DOT(bool _createToken) {
 }
 
 void GrpLexer::mOP_DOTDOT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_DOTDOT;
-	int _saveIndex;
 	
 	match("..");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1154,9 +1139,8 @@ void GrpLexer::mOP_DOTDOT(bool _createToken) {
 }
 
 void GrpLexer::mOP_COLON(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_COLON;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>(':'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1167,9 +1151,8 @@ void GrpLexer::mOP_COLON(bool _createToken) {
 }
 
 void GrpLexer::mOP_SEMI(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_SEMI;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>(';'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1180,9 +1163,8 @@ void GrpLexer::mOP_SEMI(bool _createToken) {
 }
 
 void GrpLexer::mOP_LBRACKET(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_LBRACKET;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('['));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1193,9 +1175,8 @@ void GrpLexer::mOP_LBRACKET(bool _createToken) {
 }
 
 void GrpLexer::mOP_RBRACKET(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_RBRACKET;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>(']'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1206,9 +1187,8 @@ void GrpLexer::mOP_RBRACKET(bool _createToken) {
 }
 
 void GrpLexer::mOP_LPAREN(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_LPAREN;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('('));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1219,9 +1199,8 @@ void GrpLexer::mOP_LPAREN(bool _createToken) {
 }
 
 void GrpLexer::mOP_RPAREN(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_RPAREN;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>(')'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1232,9 +1211,8 @@ void GrpLexer::mOP_RPAREN(bool _createToken) {
 }
 
 void GrpLexer::mOP_LBRACE(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_LBRACE;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('{'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1245,9 +1223,8 @@ void GrpLexer::mOP_LBRACE(bool _createToken) {
 }
 
 void GrpLexer::mOP_RBRACE(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_RBRACE;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('}'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1258,9 +1235,8 @@ void GrpLexer::mOP_RBRACE(bool _createToken) {
 }
 
 void GrpLexer::mOP_NOT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_NOT;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('!'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1271,9 +1247,8 @@ void GrpLexer::mOP_NOT(bool _createToken) {
 }
 
 void GrpLexer::mOP_LT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_LT;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('<'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1284,9 +1259,8 @@ void GrpLexer::mOP_LT(bool _createToken) {
 }
 
 void GrpLexer::mOP_LE(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_LE;
-	int _saveIndex;
 	
 	match("<=");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1297,9 +1271,8 @@ void GrpLexer::mOP_LE(bool _createToken) {
 }
 
 void GrpLexer::mOP_EQ(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_EQ;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('='));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1310,9 +1283,8 @@ void GrpLexer::mOP_EQ(bool _createToken) {
 }
 
 void GrpLexer::mOP_EQUALEQUAL(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_EQUALEQUAL;
-	int _saveIndex;
 	
 	match("==");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1323,9 +1295,8 @@ void GrpLexer::mOP_EQUALEQUAL(bool _createToken) {
 }
 
 void GrpLexer::mOP_NE(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_NE;
-	int _saveIndex;
 	
 	match("!=");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1336,9 +1307,8 @@ void GrpLexer::mOP_NE(bool _createToken) {
 }
 
 void GrpLexer::mOP_GE(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_GE;
-	int _saveIndex;
 	
 	match(">=");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1349,9 +1319,8 @@ void GrpLexer::mOP_GE(bool _createToken) {
 }
 
 void GrpLexer::mOP_GT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_GT;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('>'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1362,9 +1331,8 @@ void GrpLexer::mOP_GT(bool _createToken) {
 }
 
 void GrpLexer::mOP_PLUS(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_PLUS;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('+'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1375,9 +1343,8 @@ void GrpLexer::mOP_PLUS(bool _createToken) {
 }
 
 void GrpLexer::mOP_PLUSEQUAL(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_PLUSEQUAL;
-	int _saveIndex;
 	
 	match("+=");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1388,9 +1355,8 @@ void GrpLexer::mOP_PLUSEQUAL(bool _createToken) {
 }
 
 void GrpLexer::mOP_MINUS(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_MINUS;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('-'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1401,9 +1367,8 @@ void GrpLexer::mOP_MINUS(bool _createToken) {
 }
 
 void GrpLexer::mOP_MINUSEQUAL(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_MINUSEQUAL;
-	int _saveIndex;
 	
 	match("-=");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1414,9 +1379,8 @@ void GrpLexer::mOP_MINUSEQUAL(bool _createToken) {
 }
 
 void GrpLexer::mOP_MULT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_MULT;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('*'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1427,9 +1391,8 @@ void GrpLexer::mOP_MULT(bool _createToken) {
 }
 
 void GrpLexer::mOP_MULTEQUAL(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_MULTEQUAL;
-	int _saveIndex;
 	
 	match("*=");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1440,9 +1403,8 @@ void GrpLexer::mOP_MULTEQUAL(bool _createToken) {
 }
 
 void GrpLexer::mOP_DIV(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_DIV;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('/'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1453,9 +1415,8 @@ void GrpLexer::mOP_DIV(bool _createToken) {
 }
 
 void GrpLexer::mOP_DIVEQUAL(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_DIVEQUAL;
-	int _saveIndex;
 	
 	match("/=");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1466,9 +1427,8 @@ void GrpLexer::mOP_DIVEQUAL(bool _createToken) {
 }
 
 void GrpLexer::mOP_ANDEQUAL(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_ANDEQUAL;
-	int _saveIndex;
 	
 	match("&=");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1479,9 +1439,8 @@ void GrpLexer::mOP_ANDEQUAL(bool _createToken) {
 }
 
 void GrpLexer::mOP_COMMA(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_COMMA;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>(','));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1492,9 +1451,8 @@ void GrpLexer::mOP_COMMA(bool _createToken) {
 }
 
 void GrpLexer::mOP_DOLLAR(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_DOLLAR;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('$'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1505,9 +1463,8 @@ void GrpLexer::mOP_DOLLAR(bool _createToken) {
 }
 
 void GrpLexer::mOP_LINEMARKER(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_LINEMARKER;
-	int _saveIndex;
 	
 	match("#line");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1518,9 +1475,8 @@ void GrpLexer::mOP_LINEMARKER(bool _createToken) {
 }
 
 void GrpLexer::mOP_HASH(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_HASH;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('#'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1531,9 +1487,8 @@ void GrpLexer::mOP_HASH(bool _createToken) {
 }
 
 void GrpLexer::mOP_AND(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_AND;
-	int _saveIndex;
 	
 	match("&&");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1544,9 +1499,8 @@ void GrpLexer::mOP_AND(bool _createToken) {
 }
 
 void GrpLexer::mOP_OR(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_OR;
-	int _saveIndex;
 	
 	match("||");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1557,9 +1511,8 @@ void GrpLexer::mOP_OR(bool _createToken) {
 }
 
 void GrpLexer::mOP_BITAND(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_BITAND;
-	int _saveIndex;
 	
 	match("&");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1570,9 +1523,8 @@ void GrpLexer::mOP_BITAND(bool _createToken) {
 }
 
 void GrpLexer::mOP_BITOR(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_BITOR;
-	int _saveIndex;
 	
 	match("|");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1583,9 +1535,8 @@ void GrpLexer::mOP_BITOR(bool _createToken) {
 }
 
 void GrpLexer::mOP_BITNOT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_BITNOT;
-	int _saveIndex;
 	
 	match("~");
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1596,9 +1547,8 @@ void GrpLexer::mOP_BITNOT(bool _createToken) {
 }
 
 void GrpLexer::mOP_BSLASH(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_BSLASH;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('\\'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1609,9 +1559,8 @@ void GrpLexer::mOP_BSLASH(bool _createToken) {
 }
 
 void GrpLexer::mOP_UNDER(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_UNDER;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('_'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1622,9 +1571,8 @@ void GrpLexer::mOP_UNDER(bool _createToken) {
 }
 
 void GrpLexer::mOP_QUESTION(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_QUESTION;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('?'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1635,9 +1583,8 @@ void GrpLexer::mOP_QUESTION(bool _createToken) {
 }
 
 void GrpLexer::mOP_CARET(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = OP_CARET;
-	int _saveIndex;
 	
 	match(static_cast<unsigned char>('^'));
 	if ( _createToken && _token==nullToken && _ttype!=Token::SKIP ) {
@@ -1648,9 +1595,8 @@ void GrpLexer::mOP_CARET(bool _createToken) {
 }
 
 void GrpLexer::mIDENT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = IDENT;
-	int _saveIndex;
 	
 	{
 	switch ( LA(1)) {
@@ -1819,9 +1765,8 @@ void GrpLexer::mIDENT(bool _createToken) {
 }
 
 void GrpLexer::mAT_IDENT(bool _createToken) {
-	int _ttype; RefToken _token; int _begin=text.length();
+	int _ttype; RefToken _token; auto _begin=text.length();
 	_ttype = AT_IDENT;
-	int _saveIndex;
 	
 	{
 	if ((LA(1)==static_cast<unsigned char>('@')) && (LA(2)==static_cast<unsigned char>(':'))) {
