@@ -47,7 +47,9 @@ char* program_invocation_name;
 char* program_invocation_short_name;
 #endif
 
+#ifdef _MSC_VER
 #pragma hdrstop
+#endif
 #undef THIS_FILE
 DEFINE_THIS_FILE
 
@@ -112,8 +114,8 @@ int main(int argc, char * argv[])
 	char * pchFontFile = NULL;
 	char rgchOutputFile[128];
 	utf16 rgchwOutputFontFamily[128];
-	memset(rgchOutputFile, 0, isizeof(char) * 128);
-	memset(rgchwOutputFontFamily, 0, isizeof(utf16) * 128);
+	memset(rgchOutputFile, 0, sizeof *rgchOutputFile * 128);
+	memset(rgchwOutputFontFamily, 0, sizeof *rgchwOutputFontFamily * 128);
 
 	int cargExtra = 0;
 	bool fModFontName = false;
@@ -146,7 +148,7 @@ int main(int argc, char * argv[])
 	}
 	if (g_cman.IsVerbose())
 	{
-		std::cout << "Graphite Compiler Version 5.2";
+		std::cout << "Graphite Compiler Version 5.2.1";
 		#ifdef _DEBUG
 			std::cout << "  [debug build]";
 		#else
@@ -154,7 +156,7 @@ int main(int argc, char * argv[])
 		#endif
 		// \xc2\xa9 = copyright symbol
 		std::cout << "\n"
-			<< "Copyright (c) 2002-2020, by SIL International.  All rights reserved.\n";
+			<< "Copyright (c) 2002-2021, by SIL International.  All rights reserved.\n";
 	}
 
 	if (argc < 3 + cargExtra)
@@ -340,10 +342,10 @@ int main(int argc, char * argv[])
 	if (!fFatalErr)
 	{
 		// Calculate the length of the path part of the output file name.
-		int cchOutputPath = strlen(rgchOutputFile);
+		auto cchOutputPath = strlen(rgchOutputFile);
 		while (cchOutputPath > 0 && rgchOutputFile[cchOutputPath] != '\\' && rgchOutputFile[cchOutputPath] != '/')
 			cchOutputPath--;
-		memset(rgchOutputPath, 0, isizeof(char) * 128);
+		memset(rgchOutputPath, 0, sizeof *rgchOutputPath * 128);
 		memcpy(rgchOutputPath, rgchOutputFile, cchOutputPath); /* don't include \ */
 
 		if (g_cman.IsVerbose())
@@ -382,11 +384,9 @@ int main(int argc, char * argv[])
 				std::cout << "Please recompile with original (non-Graphite) font.\n";
 				// similar error msg already in g_errorList
 			}
-			std::cout << "Could not open font--error code = " << nFontError << "\n";
-			char rgch[20];
-			itoa(nFontError, rgch, 10);
+			std::cout << std::dec << "Could not open font--error code = " << nFontError << std::endl;
 			g_errorList.AddError(137, NULL,
-				"Could not open font--error code = ", rgch);
+				"Could not open font--error code = ", std::to_string(nFontError));
 		}
 	}
 
@@ -405,10 +405,8 @@ int main(int argc, char * argv[])
 			&& (g_cman.NameTableStart() < g_cman.NameTableStartMin()
 				|| g_cman.NameTableStart() > 32767))
 		{
-			char rgch[20];
-			itoa(g_cman.NameTableStart(), rgch, 10);
 			g_errorList.AddError(134, NULL,
-				"Invalid name table start ID: ", rgch,
+				"Invalid name table start ID: ", std::to_string(g_cman.NameTableStart()),
 				"; must be in range 256 - 32767.");
 		}
 		fFatalErr = g_errorList.AnyFatalErrors();
@@ -469,10 +467,8 @@ int main(int argc, char * argv[])
 		else
 		{
 			std::cout << "ERROR IN WRITING FONT FILE.\n";
-			char rgch[20];
-			itoa(nRet, rgch, 10);
 			g_errorList.AddError(135, NULL,
-				"Error in writing font file--error code = ", rgch);
+				"Error in writing font file--error code = ", std::to_string(nRet));
 		}
 	}
 
@@ -481,11 +477,11 @@ int main(int argc, char * argv[])
 		rgchOutputFile, staFamily,
 		VersionString(g_cman.SilfTableVersion()), g_cman.SeparateControlFile());
 
-	int cerrFatal = g_errorList.NumberOfErrors();
-	int cerrWarning = g_errorList.NumberOfWarnings();
-	int cerrWarningGiven = g_errorList.NumberOfWarningsGiven();	// ie, not ignored
-	cerrFatal = cerrFatal - cerrWarning;
-	int cerrWarningIgnored = cerrWarning - cerrWarningGiven;
+	auto cerrFatal = g_errorList.NumberOfErrors();
+	auto cerrWarning = g_errorList.NumberOfWarnings();
+	auto cerrWarningGiven = g_errorList.NumberOfWarningsGiven();	// ie, not ignored
+	cerrFatal -= cerrWarning;
+	auto cerrWarningIgnored = cerrWarning - cerrWarningGiven;
 
 	if (cerrFatal > 0)
 	{
@@ -749,12 +745,7 @@ bool LooksLikeFontFamily(char * pch)
 ----------------------------------------------------------------------------------------------*/
 std::string VersionString(int fxdVersion)
 {
-	std::string sta = "";
-	char rgch[20];
-	itoa(fxdVersion >> 16, rgch, 10);
-	sta += rgch;
-	sta += ".";
-	itoa(fxdVersion & 0x0000FFFF, rgch, 10);
-	sta += rgch;
-	return sta;
+	return std::to_string(fxdVersion >> 16) 
+		 + '.' 
+		 + std::to_string(fxdVersion & 0x0000FFFF);
 }
