@@ -26,8 +26,6 @@ Description:
 ----------------------------------------------------------------------------------------------*/
 int CompareFontTables(TestCase * ptcase, GrcRtFileFont * pfontBmark, GrcRtFileFont * pfontTest)
 {
-	bool fOk = false;
-
 	int ec = 0; // error count
 
 	// benchmark font buffers
@@ -174,6 +172,7 @@ int CompareFontTables(TestCase * ptcase, GrcRtFileFont * pfontBmark, GrcRtFileFo
 
 	// Silf
 	try {
+		pSilfTblT = NULL;
 		if ((pSilfTblB = static_cast<const gr::byte *> (pfontBmark->getTable(TtfUtil::TableIdTag(ktiSilf), &cbSilfSzB))) == NULL)
 			OutputError(ec, ptcase, "ERROR: benchmark font has empty Silf table");
 		else
@@ -446,8 +445,8 @@ void CompareSilfTables(int & ec, TestCase * ptcase, GrIStream & grstrmB, GrIStre
 	grstrmT.GetPositionInFont(&lSubTableStartT);
 
 	//	rule version
-	int fxdRuleVersionB = (fxdSilfVersionB >= 0x00030000) ? ReadVersion(grstrmB) : fxdSilfVersionB;
-	int fxdRuleVersionT = (fxdSilfVersionT >= 0x00030000) ? ReadVersion(grstrmT) : fxdSilfVersionT;
+	uint32_t fxdRuleVersionB = (fxdSilfVersionB >= 0x00030000) ? ReadVersion(grstrmB) : fxdSilfVersionB;
+	uint32_t fxdRuleVersionT = (fxdSilfVersionT >= 0x00030000) ? ReadVersion(grstrmT) : fxdSilfVersionT;
 
 	long lPassBlockPosB = -1;
 	long lPseudosPosB = -1;
@@ -1194,7 +1193,7 @@ void CompareGlatAndGlocTables(int & ec, TestCase * ptcase, int wMaxGlyphID,
 		OutputErrorWithValues(ec, ptcase, "ERROR: Gloc table - offset", 0, nOffsetB, nOffsetT);
 	int iAttrEntry = 0;
 	int cbGlatOffset = 4; // read version
-	for (int wGlyphID = 1; wGlyphID < wMaxGlyphID; wGlyphID++)
+	for (gid16 wGlyphID = 1; wGlyphID < wMaxGlyphID; wGlyphID++)
 	{
 		int nOffsetBnext = fLongFormatB ? grstrmGlocB.ReadIntFromFont() : grstrmGlocB.ReadUShortFromFont();
 		while (cbGlatOffset < nOffsetBnext)
